#
# spec file for package oqs-provider
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           oqs-provider
Version:        0.5.1
Release:        1.2
Summary:        Quantum-safe crypto provider for OpenSSL
License:        MIT
Group:          Productivity/Security
URL:            https://github.com/open-quantum-safe/oqs-provider/
Source:         https://github.com/open-quantum-safe/oqs-provider/archive/refs/tags/%{version}.tar.gz#/%name-%version.tar.gz
# currently would need libtestutil.a from openssl-3, so basically a copy of openssl-3 to test.
Patch1:         oqs-provider-disable-test.patch
BuildRequires:  cmake
BuildRequires:  libopenssl-3-devel
BuildRequires:  pkgconfig(liboqs)

%description
This is a plugin/shared library making available quantum-safe cryptography
(QSC) to OpenSSL 3.x installations via the Provider API.

Sample call:

openssl-3 ciphers -provider oqsprovider

%prep
%autosetup

%build
mkdir build
export RPM_OPT_FLAGS="%optflags -std=gnu11"
cd build
cmake -DBUILD_SHARED_LIBS=ON ..
%cmake_build

%install
install -d %buildroot/%{_libdir}/ossl-modules/

install -m 755 -c build/lib/oqsprovider.so %buildroot/%{_libdir}/ossl-modules/

%files
%license LICENSE.txt
%dir /%{_libdir}/ossl-modules
/%{_libdir}/ossl-modules/oqsprovider.so

%changelog
* Tue Sep 19 2023 Marcus Meissner <meissner@suse.com>
- updated to 0.5.1
  - Documentation update
  - document specs
  - General documentation overhaul
  - change TLS demo to use QSC alg
  - Build a module instead of a shared library.
  - explain groups in USAGE
* Tue Jun 13 2023 Marcus Meissner <meissner@suse.com>
- updated to 0.5.0:
  - oqs-provider now also enables use of QSC algorithms during TLS1.3
    handshake. The required OpenSSL code updates are contained in
    openssl/openssl#19312.
  * Algorithm updates
    All algorithms no longer supported in the NIST PQC competition
    and not under consideration for standardization by ISO have been
    removed. All remaining algorithms with the exception of McEliece
    have been lifted to their final round 3 variants as documented in
    liboqs. Most notably, algorithm names for Sphincs+ have been changed
    to the naming chosen by its authors.
  * Functional updates
  - Enablement of oqs-provider as a (first) dynamically fetchable OpenSSL3 TLS1.3 signature provider.
  - OSX support
  - Full support for CA functionality
  - Algorithms can now be selected by their respective bit strength using the property string "oqsprovider.security_bits"
  - Documentation of (O)IDs used by the different PQC algorithms used and supported in current and past releases of oqs-openssl and oqs-provider
  - Graceful handling (by way of functional degradation) of the feature sets contained in different OpenSSL releases; all oqsprovider capabilities are only available when using a version > than OpenSSL3.1.
  - A bug regarding handling of hybrid algorithms has been fixed as well as some memory leaks.
  * Misc updates
  - Dynamic code point and OID changes via environment variables. See ALGORITHMS.md.
  - Dynamic key encoding changes via environment variable using external qsc_key_encoder library. See ALGORITHMS.md.
- oqs-provider-shared-liboqs.patch: removed, not needed anymore
- updated to 0.4.0:
  * Security considerations
  - This release removes Rainbow level 1 and all variants of SIDH and
    SIKE due to cryptanalytic breaks of those algorithms. Users are advised
    to move away from use of those algorithms immediately.
  * Algorithm updates
  - Removal of SIKE/SIDH and Rainbow level I due to cryptographic breaks
  * Functional updates
  - Addition of quantum-safe CMS operations via the OpenSSL interface
  - Addition of quantum-safe dgst operations via the OpenSSL interface
  * Misc updates
  - Additional testing
  - Integration with and of OpenSSL test harness
* Tue Nov 15 2022 Jan Engelhardt <jengelh@inai.de>
- Update descriptions
* Mon Nov 14 2022 Marcus Meissner <meissner@suse.com>
- initial import of openssl-3 plugin for liboqs
